==> aldo-0.6.3.tar.bz2: aldo-0.6.3/src/check.cpp <==
/***************************************************************************
                                 Aldo
                          --------------------
    begin                : Sun May 6 2001
    copyleft             : Giuseppe "denever" Martino
    email                : denever@users.sourceforge.net
 ***************************************************************************/
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program; if not, write to the Free Software            *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
 *                                                                         *
 ***************************************************************************/

#include "resources.h"
#include "classic.h"

#include <iostream>
#include <string>

using namespace std;

unsigned int check(const libmorse::Classic& current_exercise)
{
    string catched_strings;
    
    cout<<endl<<chkmsg_1<<endl;
    cout<<chkmsg_4<<endl;
    
    for(unsigned int i=0; i<current_exercise.len(); i++)
    {
	string tmp;
	cout<<(i+1)<<": ";
	cin>>tmp;
	catched_strings += tmp;
    }

    unsigned int catched = current_exercise.verify(catched_strings);

    cout<<catched<<chkmsg_2<<endl<<endl;

    cout<<chkmsg_3<<endl;
    
    std::string tmp = current_exercise.get_string();
    unsigned int strlen = current_exercise.string_len();
    
    for(unsigned int i=0; i<current_exercise.len(); i++)
    	cout<<(i+1)<<": "<<tmp.substr(i*strlen,strlen)<<endl;
	
    cout<<endl<<endl;
    return catched;
}

==> aldo-0.6.6.tar.bz2: aldo-0.6.6/src/check.cpp <==
/***************************************************************************
                                 Aldo
                          --------------------
    begin                : Sun May 6 2001
    copyleft             : Giuseppe "denever" Martino
    email                : denever@users.sourceforge.net
 ***************************************************************************/
/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program; if not, write to the Free Software            *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
 *                                                                         *
 ***************************************************************************/

#include "resources.h"
#include "classic.h"

#include <iostream>
#include <string>

using namespace std;

unsigned int check(const libexercises::Classic& current_exercise)
{
    string catched_strings;
    
    cout<<endl<<chkmsg_1<<endl;
    cout<<chkmsg_4<<endl;
    
    for(unsigned int i=0; i<current_exercise.len(); i++)
    {
	string tmp;
	cout<<(i+1)<<": ";
	cin>>tmp;
	catched_strings += tmp;
    }

    unsigned int catched = current_exercise.verify(catched_strings);

    cout<<catched<<chkmsg_2<<endl<<endl;

    cout<<chkmsg_3<<endl;
    
    std::string tmp = current_exercise.get_string();
    unsigned int strlen = current_exercise.string_len();
    
    for(unsigned int i=0; i<current_exercise.len(); i++)
    	cout<<(i+1)<<": "<<tmp.substr(i*strlen,strlen)<<endl;
	
    cout<<endl<<endl;
    return catched;
}
